aboutsummaryrefslogtreecommitdiffstats
path: root/parameter/Subsystem.h
diff options
context:
space:
mode:
authorFrédéric Boisnard <fredericx.boisnard@intel.com>2013-07-19 17:17:52 +0200
committerDavid Wagner <david.wagner@intel.com>2014-02-12 17:04:04 +0100
commit487ce850cc5f884f7689a2bfd55a7e1cf6eb3053 (patch)
treeb2597c6160b91248f16095c5a7d6f426e6c47d10 /parameter/Subsystem.h
parent6cae0ecf49ec7815aa59a4f4a0ec99976ca38032 (diff)
downloadexternal_parameter-framework-487ce850cc5f884f7689a2bfd55a7e1cf6eb3053.zip
external_parameter-framework-487ce850cc5f884f7689a2bfd55a7e1cf6eb3053.tar.gz
external_parameter-framework-487ce850cc5f884f7689a2bfd55a7e1cf6eb3053.tar.bz2
[PFW] Fix typo in the naming of the SubsystemBuilder API
BZ: 124779 There is a typo in the naming of the SubsystemBuilder API, "Susbystem" is used instead of "Subsystem". This patch replaces all occurences of "Susbystem" with "Subsystem". Change-Id: Ic132bdc685013257a138465545b99d001c46535a Signed-off-by: Frédéric Boisnard <fredericx.boisnard@intel.com> Reviewed-on: http://android.intel.com:8080/120166 Reviewed-by: Denneulin, Guillaume <guillaume.denneulin@intel.com> Reviewed-by: De Chivre, Renaud <renaud.de.chivre@intel.com> Tested-by: Barthes, FabienX <fabienx.barthes@intel.com> Reviewed-by: buildbot <buildbot@intel.com> Tested-by: buildbot <buildbot@intel.com>
Diffstat (limited to 'parameter/Subsystem.h')
-rw-r--r--parameter/Subsystem.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/parameter/Subsystem.h b/parameter/Subsystem.h
index 277ff25..abd6c39 100644
--- a/parameter/Subsystem.h
+++ b/parameter/Subsystem.h
@@ -160,7 +160,7 @@ private:
/**
* Find the mapping data defined for the CInstanceConfigurableElement given in parameter, that
* corresponds to Susbystem level mapping (Susbystem level mapping keys are defined in
* CSubsystemObjectCreator classes).
* The CInstanceConfigurableElement might as well contain local mapping data.
*
@@ -169,7 +169,7 @@ private:
* @param[out] strMappingKey Mapping key defined at the Subsystem level
* @param[out] strMappingValue Mapping value contained in pInstanceConfigurableElement
*/
- void findSusbystemLevelMappingKeyValue(
+ void findSubsystemLevelMappingKeyValue(
const CInstanceConfigurableElement* pInstanceConfigurableElement,
string& strMappingKey,
string& strMappingValue) const;
@@ -160,7 +160,7 @@ private:
/**
* Find the mapping data defined for the CInstanceConfigurableElement given in parameter, that
- * corresponds to Susbystem level mapping (Susbystem level mapping keys are defined in
+ * corresponds to Subsystem level mapping (Subsystem level mapping keys are defined in
* CSubsystemObjectCreator classes).
* The CInstanceConfigurableElement might as well contain local mapping data.